@@ -102,7 +102,7 @@ class TestMongoScheduler:
         scheduler.sync()
 
         # Verify the document in the DB was updated
-        task_doc = manager.get_task('sync-test-task')
+        task_doc = manager.get_task(name='sync-test-task')
         assert task_doc is not None
         # mongomock may return a naive datetime, so we make it aware before comparing.
         db_last_run_at = task_doc['last_run_at'].replace(tzinfo=datetime.timezone.utc)
@@ -131,7 +131,7 @@ class TestMongoScheduler:
         scheduler.sync()
 
         # Verify the task is now disabled in the database
-        task_doc = manager.get_task('limited-run-task')
+        task_doc = manager.get_task(name='limited-run-task')
         assert task_doc is not None
         assert task_doc['enabled'] is False
         assert task_doc['total_run_count'] == 3
@@ -261,6 +261,23 @@ class TestMongoScheduler:
         assert entry.task == 'tasks.db_version'
         assert entry.schedule.run_every.total_seconds() == 30
 
+    def test_max_interval_configuration(self, celery_app, monkeypatch):
+        """Test that max_interval is set correctly from config and has a default."""
+        # To avoid real DB connections, we patch MongoClient for this test
+        monkeypatch.setattr('src.celery_mongobeat.beat.MongoClient', lambda *args, **kwargs: MagicMock())
+
+        # --- Test Case 1: Value is set in config ---
+        celery_app.conf.beat_max_loop_interval = 60
+        scheduler_with_config = MongoScheduler(app=celery_app)
+        assert scheduler_with_config.max_interval == 60
+
+        # --- Test Case 2: Value is NOT set in config ---
+        # The parent Scheduler sets beat_max_loop_interval to None if not present
+        celery_app.conf.beat_max_loop_interval = None
+        scheduler_with_default = MongoScheduler(app=celery_app)
+        # Verify it falls back to the hardcoded default of 300
+        assert scheduler_with_default.max_interval == 300
+
 
 class TestScheduleManager:
     """
@@ -277,32 +294,77 @@ class TestScheduleManager:
         assert manager.collection.database.name == 'test_db'
         assert manager.collection.name == 'schedules'
 
+    def test_from_celery_app_auto_discovery(self, celery_app, mock_mongo_client, monkeypatch):
+        """
+        Test that from_celery_app correctly discovers the current app when none is provided.
+        """
+        # Patch `celery.current_app` to return our test app fixture
+        mock_current_app = MagicMock()
+        mock_current_app._get_current_object.return_value = celery_app
+        monkeypatch.setattr('src.celery_mongobeat.helpers.celery_current_app', mock_current_app)
+
+        # Patch MongoClient to use the mock client
+        monkeypatch.setattr('src.celery_mongobeat.helpers.MongoClient', lambda *args, **kwargs: mock_mongo_client)
+
+        # Call from_celery_app without an app argument to test auto-discovery
+        manager = ScheduleManager.from_celery_app()
+
+        # Assert that the manager was configured correctly from the discovered app
+        assert manager.collection.database.name == 'test_db'
+        assert manager.collection.name == 'schedules'
+
     def test_create_and_get_task(self, manager):
-        """Test creating and retrieving a task."""
-        manager.create_interval_task('test-get', 'tasks.get', 1, 'seconds', args=[1], kwargs={'a': 1})
-        task = manager.get_task('test-get')
+        """Test creating, updating, and retrieving a task, and verify ObjectId return."""
+        # 1. Test creation: A new task should return the full document.
+        created_doc = manager.create_interval_task('test-get', 'tasks.get', 1, 'seconds', args=[1], kwargs={'a': 1})
+        assert isinstance(created_doc, dict)
+        assert isinstance(created_doc['_id'], ObjectId)
+        task_id = created_doc['_id']
+
+        # 2. Test retrieval: The retrieved task should have the correct data.
+        task = manager.get_task(name='test-get')
         assert task is not None
+        assert task['_id'] == task_id
         assert task['task'] == 'tasks.get'
         assert task['args'] == [1]
         assert task['kwargs'] == {'a': 1}
 
+        # 3. Test retrieval by ID: The retrieved task should be the same.
+        task_by_id = manager.get_task(id=task_id)
+        assert task_by_id is not None
+        assert task_by_id['name'] == 'test-get'
+
+        # 4. Test update: Updating the same task should return a document with the same ObjectId.
+        updated_doc = manager.create_interval_task('test-get', 'tasks.get.updated', 2, 'seconds')
+        assert isinstance(updated_doc, dict)
+        assert updated_doc['_id'] == task_id
+
     def test_enable_disable_task(self, manager):
         """Test enabling and disabling a task."""
         manager.create_interval_task('test-enable', 'tasks.test', 1, 'seconds')
         manager.disable_task('test-enable')
-        task = manager.get_task('test-enable')
+        task = manager.get_task(name='test-enable')
         assert task['enabled'] is False
 
         manager.enable_task('test-enable')
-        task = manager.get_task('test-enable')
+        task = manager.get_task(name='test-enable')
         assert task['enabled'] is True
 
     def test_delete_task(self, manager):
         """Test deleting a task."""
-        manager.create_interval_task('test-delete', 'tasks.test', 1, 'seconds')
-        assert manager.get_task('test-delete') is not None
-        manager.delete_task('test-delete')
-        assert manager.get_task('test-delete') is None
+        # Create two tasks to test deletion by name and by id
+        task1 = manager.create_interval_task('delete-by-name', 'tasks.test', 1, 'seconds')
+        task2 = manager.create_interval_task('delete-by-id', 'tasks.test', 1, 'seconds')
+
+        # Verify deletion by name
+        assert manager.get_task(name='delete-by-name') is not None
+        manager.delete_task(name='delete-by-name')
+        assert manager.get_task(name='delete-by-name') is None
+
+        # Verify deletion by id
+        assert manager.get_task(id=task2['_id']) is not None
+        manager.delete_task(id=task2['_id'])
+        assert manager.get_task(name='test-delete') is None
 
     def test_get_tasks_with_filters(self, manager):
         """Test filtering tasks with get_tasks."""
@@ -337,7 +399,7 @@ class TestScheduleManager:
         )
 
         # Test get_task with serialization
-        task = manager.get_task('serialize-test', serialize=True)
+        task = manager.get_task(name='serialize-test', serialize=True)
         assert task is not None
         assert isinstance(task['_id'], str)
         # Parse the serialized datetime string and compare with a tolerance
@@ -356,4 +418,68 @@ class TestScheduleManager:
         serialized_dt_from_list_aware = serialized_dt_from_list_naive.replace(
             tzinfo=datetime.timezone.utc
         )
-        assert abs(serialized_dt_from_list_aware - now) < datetime.timedelta(seconds=1)
\ No newline at end of file
+        assert abs(serialized_dt_from_list_aware - now) < datetime.timedelta(seconds=1)
+
+    def test_create_task_from_dictionary(self, manager):
+        """Test creating a task by unpacking a dictionary with custom fields."""
+        task_data = {
+            'name': 'task-from-dict',
+            'task': 'tasks.dict_task',
+            'every': 30,
+            'period': 'minutes',
+            'description': 'A task created from a dictionary.',
+            'display_name': 'My Dictionary Task'  # Custom field
+        }
+
+        # Use dictionary unpacking to pass all data
+        created_doc = manager.create_interval_task(**task_data)
+        assert created_doc is not None
+
+        # Verify that the custom field was saved correctly
+        assert created_doc['display_name'] == 'My Dictionary Task'
+        assert created_doc['description'] == 'A task created from a dictionary.'
+        assert created_doc['interval']['every'] == 30
+
+    def test_create_task_with_custom_fields(self, manager):
+        """Test that arbitrary keyword arguments are saved as custom fields."""
+        manager.create_interval_task(
+            'task-with-custom-fields',
+            'tasks.test',
+            1, 'seconds',
+            owner='data-team',
+            priority=100
+        )
+        task = manager.get_task(name='task-with-custom-fields')
+        assert task is not None
+        assert task['owner'] == 'data-team'
+        assert task['priority'] == 100
+
+    def test_update_task(self, manager):
+        """Test updating a task using various identification methods."""
+        # Create an initial task
+        created_doc = manager.create_interval_task(
+            'task-to-update', 'tasks.test', 1, 'seconds', description='Initial'
+        )
+        task_id = created_doc['_id']
+
+        # 1. Update by name
+        updated_doc_by_name = manager.update_task(name='task-to-update', description='Updated by name')
+        assert updated_doc_by_name is not None
+        assert updated_doc_by_name['description'] == 'Updated by name'
+
+        # 2. Update by ID
+        updated_doc_by_id = manager.update_task(id=task_id, description='Updated by ID')
+        assert updated_doc_by_id is not None
+        assert updated_doc_by_id['description'] == 'Updated by ID'
+
+        # 3. Update using `name` from data payload
+        updated_doc_from_data_name = manager.update_task(description='Updated from data name', name='task-to-update')
+        assert updated_doc_from_data_name['description'] == 'Updated from data name'
+
+        # 4. Update using `_id` from data payload
+        updated_doc_from_data_id = manager.update_task(description='Updated from data id', _id=task_id)
+        assert updated_doc_from_data_id['description'] == 'Updated from data id'
+
+        # 5. Update using `id` (as string) from data payload
+        updated_doc_from_data_id_str = manager.update_task(description='Updated from data id string', id=str(task_id))
+        assert updated_doc_from_data_id_str['description'] == 'Updated from data id string'
\ No newline at end of file
